package devmgr.api.model;

import io.swagger.annotations.ApiModelProperty;
import devmgr.api.symbol.ProtectionType;

/**
 * Objects that support copy operations like VolumeCopy, ARVM, RVM, and Snapshots.
 */
public interface CopyableObject {
    public void setVolumeCopyTarget(boolean v);
    public void setVolumeCopySource(boolean v);
    public void setOnlineVolumeCopy(boolean c);
    public void setPitBaseVolume(boolean v);
    public boolean isVolumeCopyTarget();
    public boolean isVolumeCopySource();
    public boolean isPitBaseVolume();
    public boolean isOnlineVolumeCopy();
    public Long getTotalSizeInBytes();
    public String getName();
    public String getId();
    public ProtectionType getProtectionType();

    /**
     * @API_Spec_Description True if the volume is a source in an Remote Volume Mirror relationship.
     */
    @ApiModelProperty("True if the volume is a source (primary), in an Remote Volume Mirror relationship.")
    public boolean isRemoteMirrorSource();

    @ApiModelProperty("True if the volume is a target (secondary), in an Remote Volume Mirror relationship.")
    public boolean isRemoteMirrorTarget();

    /**
     * @API_Spec_Description True if the volume is a source in an Asynchronous Mirror relationship.
     */
    @ApiModelProperty("True if the volume is a source in an Asynchronous Mirror relationship.")
    public boolean isAsyncMirrorSource();

    /**
     * @API_Spec_Description True if the volume is a target in an Asynchronous Mirror relationship.
     */
    @ApiModelProperty("True if the volume is a target in an Asynchronous Mirror relationship.")
    public boolean isAsyncMirrorTarget();

    /**
     * @API_Spec_Description Set to true if this volume is local in an AMG that is secondary.
     */
    public void setAsyncMirrorTarget(boolean v);

    /**
     * @API_Spec_Description Set to true if this volume is local in an AMG that is primary.
     */
    public void setAsyncMirrorSource(boolean v);

    public void setRemoteMirrorTarget(boolean v);
    public void setRemoteMirrorSource(boolean v);

}
