package devmgr.api.model;

import io.swagger.annotations.ApiModelProperty;
import devmgr.api.symbol.LUNMapping;
import devmgr.api.symbol.ProtectionType;
import devmgr.api.symbol.SnapshotVolume;
    
import javax.xml.bind.annotation.XmlRootElement;
import java.util.ArrayList;
import java.util.List;

/**
 * User: lorenp
 * Date: 2/12/14
 * Time: 11:56 AM
 * Augmented LegacySnapshot
 * @see devmgr.api.symbol.SnapshotVolume
 */
@XmlRootElement
public class LegacySnapshotEx extends SnapshotVolume implements MappableObject, CopyableObject {
    private List<LUNMapping> mappings = new ArrayList<>();

    /**
     * The capacity of the base volume in bytes.
     * @return
     */
    public Long getBaseVolumeSizeInBytes() {
        return baseVolumeSizeInBytes;
    }

    public void setBaseVolumeSizeInBytes(long baseVolumeSizeInBytes) {
        this.baseVolumeSizeInBytes = baseVolumeSizeInBytes;
    }

    private long baseVolumeSizeInBytes;

    public void setTotalSizeInBytes(long totalSizeInBytes) {
        this.totalSizeInBytes = totalSizeInBytes;
    }

    public void setPreferredControllerId(String preferredControllerId) {
        this.preferredControllerId = preferredControllerId;
    }

    private long totalSizeInBytes;

    /**
     * The underlying volume type of the MappableObject
     *
     * @return
     */
    @Override
    public ObjectType getObjectType() {
        return ObjectType.legacySnapshot;
    }

    /**
     * Returns the Id for the object
     *
     * @return
     */
    @Override
    public String getId() {
        return getSnapshotRef();
    }

    /**
     * The world-wide name of the volume.
     */
    @Override
    public String getWwn() {
        return getWorldWideName();  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * The user-assigned label of the volume.
     */
    @Override
    public String getName() {
        return getLabel();  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * The storage capacity of the snapshot volume.
     */
    @Override
    public Long getTotalSizeInBytes() {
        return totalSizeInBytes;  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * Add mapping to the list of mappings.
     * @param mapping
     */
    public void setMapping(LUNMapping mapping) {
        this.mappings.add(mapping);
    }

    /**
     * The set of Host-to-VolumeEx LUN number mappings.
     */
    @Override
    public List<LUNMapping> getListOfMappings() {
        return mappings;  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * Set the list of lun mappings
     * @param mappings
     */
    @Override
    public void setMappings(List<LUNMapping> mappings) {
        this.mappings = mappings;
    }

    /**
     * Set to "true" when the volume has a valid mapping.
     */
    @Override
    public boolean isMapped() {
        return (mappings.size() > 0);  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * The reference value of the controller that currently owns (i.e. manages)
     * the volume. In non-Auto Volume Transfer (non-AVT) mode, host I/O access to the blocks in this
     * volume is permitted only through the controller that is the current owner. In AVT mode, an
     * I/O access to the controller that is not the current owner causes it to automatically become
     * the current owner.
     */
    @Override
    public String getCurrentControllerId() {
        return getCurrentManager();
    }

    private String preferredControllerId;

    /**
     * The identifier of the controller that is the preferred owner of the
     * volume. The preferred owner is tracked independent of the current owner, since the current owner
     * may be switched dynamically as a result of host-based multi-path transitions. Later, when the
     * error conditions that cause a multi-path transition have been corrected it is still possible
     * to determine the preferred owner and switch ownership back to it.
     */
    @Override
    public String getPreferredControllerId() {
        return preferredControllerId;
    }

    private long repositoryCapacity;

    /**
     * Aggregate capacity of all repository volumes
     */
    public Long getRepositoryCapacity() {
        return repositoryCapacity;
    }

    public void setRepositoryCapacity(long repositoryCapacity) {
        this.repositoryCapacity = repositoryCapacity;
    }

    private boolean volumeCopyTarget;
    private boolean cloneCopy;
    private boolean volumeCopySource;
    private boolean pitBaseVolume;
    private boolean asyncMirrorTarget;
    private boolean asyncMirrorSource;

    @Override
    public void setVolumeCopyTarget(boolean v) {
        this.volumeCopyTarget = v;
    }

    @Override
    public void setVolumeCopySource(boolean v) {
        this.volumeCopySource = v;
    }

    @Override
    public void setOnlineVolumeCopy(boolean c) {
        this.cloneCopy = c;
    }

    @Override
    public void setPitBaseVolume(boolean v) {
        this.pitBaseVolume = v;
    }

    @Override
    public boolean isVolumeCopyTarget() {
        return volumeCopyTarget;
    }

    @Override
    public boolean isVolumeCopySource() {
        return volumeCopySource;
    }

    @Override
    public boolean isPitBaseVolume() {
        return pitBaseVolume;
    }

    @Override
    public boolean isOnlineVolumeCopy() {
        return cloneCopy;
    }

    /**
     * @API_Spec_Description True if the volume is a source in an Asynchronous Mirror relationship.
     */
    @Override
    public boolean isAsyncMirrorSource() {
        return asyncMirrorSource;  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * @API_Spec_Description True if the volume is a target in an Asynchronous Mirror relationship.
     */
    @Override
    public boolean isAsyncMirrorTarget() {
        return asyncMirrorTarget;  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * @API_Spec_Description Set to true if this volume is local in an AMG that is secondary.
     */
    @Override
    public void setAsyncMirrorTarget(boolean v) {
        this.asyncMirrorTarget = v;
    }

    /**
     * @API_Spec_Description Set to true if this volume is local in an AMG that is primary.
     */
    @Override
    public void setAsyncMirrorSource(boolean v) {
        this.asyncMirrorSource = v;
    }

    private ProtectionType protectionType = ProtectionType.__UNDEFINED;

    /**
     * @API_Spec_Description This field provides the protection type for the volume.
     **/
    public ProtectionType getProtectionType() {
        return this.protectionType;
    }

    /**
     * @API_Spec_Description This field provides the protection type for the volume.
     **/
    public void setProtectionType(ProtectionType x) {
        this.protectionType = x;
    }

    private boolean remoteMirrorSource;

    @Override
    public void setRemoteMirrorTarget(boolean remoteMirrorTarget) {
        this.remoteMirrorTarget = remoteMirrorTarget;
    }

    @Override
    @ApiModelProperty("True if the volume is a source (primary), in an Remote Volume Mirror relationship.")
    public boolean isRemoteMirrorSource() {
        return this.remoteMirrorSource;
    }

    @Override
    @ApiModelProperty("True if the volume is a target (secondary), in an Remote Volume Mirror relationship.")
    public boolean isRemoteMirrorTarget() {
        return this.remoteMirrorTarget;
    }

    @Override
    public void setRemoteMirrorSource(boolean remoteMirrorSource) {
        this.remoteMirrorSource = remoteMirrorSource;
    }

    private boolean remoteMirrorTarget;

}
