package devmgr.api.model;

import devmgr.api.symbol.ControllerDNSProperties;
import devmgr.api.symbol.ControllerNTPProperties;
import devmgr.api.symbol.EthernetInterface;

import javax.xml.bind.annotation.XmlTransient;

/**
 * User: lorenp
 * Date: 8/14/14
 * Time: 3:31 PM
 */
public class ManagementInterface extends EthernetInterface implements Comparable<ManagementInterface> {

    public String getId(){
        return getInterfaceRef();
    }

    /**
     * @return The 32-bit IP protocol address assigned to the interface.
     */
    public int getIp() {
        return super.getIp();
    }

    private String ipv4GatewayAddress;

    public String getIpv4GatewayAddress() {
        return ipv4GatewayAddress;
    }

    public void setIpv4GatewayAddress(String ipv4GatewayAddress) {
        this.ipv4GatewayAddress = ipv4GatewayAddress;
    }

    private String controllerRef;

    public int getControllerSlot() {
        return controllerSlot;
    }

    public void setControllerSlot(int controllerSlot) {
        this.controllerSlot = controllerSlot;
    }

    public String getControllerRef() {
        return controllerRef;
    }

    public void setControllerRef(String controllerRef) {
        this.controllerRef = controllerRef;
    }

    private int controllerSlot;

    private ControllerDNSProperties dnsProperties;

    private ControllerNTPProperties ntpProperties;

    @Override
    public boolean equals(Object o) {
        String interfaceRef = getInterfaceRef();
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        ManagementInterface that = (ManagementInterface) o;

        if (interfaceRef != null ? !interfaceRef.equals(that.getInterfaceRef()) : that.getInterfaceRef() != null)
            return false;

        return true;
    }

    @Override
    public int hashCode() {
        String interfaceRef = getInterfaceRef();
        return interfaceRef != null ? interfaceRef.hashCode() : 0;
    }

    /**
     * Orders interfaces first by controller slot, and second by channel
     * @param o the object to be compared.
     * @return a negative integer, zero, or a positive integer as this object
     *         is less than, equal to, or greater than the specified object.
     * @throws NullPointerException if the specified object is null
     * @throws ClassCastException   if the specified object's type prevents it
     *                              from being compared to this object.
     */
    @Override
    public int compareTo(ManagementInterface o) {
        int value = Integer.compare(this.getControllerSlot(), o.getControllerSlot());
        if(value == 0){
            value = Integer.compare(this.getChannel(), o.getChannel());
        }
        return value;
    }


    public void setDnsProperties(ControllerDNSProperties dnsProperties) {
        this.dnsProperties = dnsProperties;
    }

    public void setNtpProperties(ControllerNTPProperties ntpProperties) {
        this.ntpProperties = ntpProperties;
    }

    public ControllerDNSProperties getDnsProperties() {
        return dnsProperties;
    }

    public ControllerNTPProperties getNtpProperties() {
        return ntpProperties;
    }
}
