package devmgr.api.model;

import io.swagger.annotations.ApiModelProperty;
import devmgr.api.symbol.LUNMapping;
import devmgr.api.symbol.PITView;
import devmgr.api.symbol.ProtectionType;

import javax.xml.bind.annotation.XmlRootElement;
import java.util.ArrayList;
import java.util.List;

/**
 * Created with IntelliJ IDEA.
 * User: lorenp
 * Date: 1/7/14
 * Time: 1:42 PM
 * To change this template use File | Settings | File Templates.
 */
@XmlRootElement
public class PitViewEx extends PITView implements MappableObject, CopyableObject {
    private List<LUNMapping> mappings = new ArrayList<>();
    private boolean volumeFull;
    private long repositoryCapacity;
    private long baseVolumeCapacity;
    private long totalSizeInBytes;
    private String consistencyGroupId;

    /**
     * Capacity of the base volume in bytes
     *
     * @return
     */
    public Long getBaseVolumeCapacity() {
        return baseVolumeCapacity;
    }

    public void setBaseVolumeCapacity(long baseVolumeCapacity) {
        this.baseVolumeCapacity = baseVolumeCapacity;
    }

    /**
     * Aggregate capacity of all repository volumes in bytes
     */
    public long getRepositoryCapacity() {
        return repositoryCapacity;
    }

    public void setRepositoryCapacity(long repositoryCapacity) {
        this.repositoryCapacity = repositoryCapacity;
    }

    /**
     * The underlying volume type of the MappableObject
     *
     * @return
     */
    @Override
    public ObjectType getObjectType() {
        return ObjectType.pitView;
    }

    /**
     * "true" if the the repository is full
     *
     * @return
     */
    public boolean isVolumeFull() {
        return volumeFull;
    }

    public void setVolumeFull(boolean volumeFull) {
        this.volumeFull = volumeFull;
    }

    /**
     * Returns the Id/Ref for the object
     *
     * @return
     */
    @Override
    public String getId() {
        return getViewRef();
    }

    @Override
    public void setMappings(List<LUNMapping> mappings) {
        this.mappings = mappings;
    }

    /**
     * The world-wide name of the volume.
     */
    @Override
    public String getWwn() {
        return getWorldWideName();
    }

    /**
     * The user-assigned label of the volume.
     */
    @Override
    public String getName() {
        return getLabel();
    }

    /**
     * The total storage capacity of the view.
     */
    @Override
    public Long getTotalSizeInBytes() {
        return totalSizeInBytes;
    }

    public void setTotalSizeInBytes(long totalSizeInBytes) {
        this.totalSizeInBytes = totalSizeInBytes;
    }
    
    /**
     * The consistency group id the PitView belongs to.
     */
    public String getConsistencyGroupId() {
   	 return consistencyGroupId;
    }
    
    public void setConsistencyGroupId(String consistencyGroupId) {
   	 this.consistencyGroupId = consistencyGroupId;
    }

    /**
     * The set of Host-to-Volume LUN number mappings.
     */
    @Override
    public List<LUNMapping> getListOfMappings() {
        return mappings;
    }

    /**
     * Set to "true" when the volume has a valid mapping.
     */
    @Override
    public boolean isMapped() {
        return mappings.size() > 0;
    }

    public void setMapping(LUNMapping mapping) {
        this.mappings.add(mapping);
    }

    public void clearMappings() {
        this.mappings = new ArrayList<>();
    }

    /**
     * The reference value of the controller that currently owns (i.e. manages)
     * the volume. In non-Auto Volume Transfer (non-AVT) mode, host I/O access to the blocks in this
     * volume is permitted only through the controller that is the current owner. In AVT mode, an
     * I/O access to the controller that is not the current owner causes it to automatically become
     * the current owner.
     */
    @Override
    public String getCurrentControllerId() {
        return getCurrentManager();
    }

    /**
     * The identifier of the controller that is the preferred owner of the
     * volume. The preferred owner is tracked independent of the current owner, since the current owner
     * may be switched dynamically as a result of host-based multi-path transitions. Later, when the
     * error conditions that cause a multi-path transition have been corrected it is still possible
     * to determine the preferred owner and switch ownership back to it.
     */
    @Override
    public String getPreferredControllerId() {
        return getPreferredManager();
    }

    private boolean volumeCopyTarget;
    private boolean cloneCopy;
    private boolean volumeCopySource;
    private boolean pitBaseVolume;

    public boolean isCloneCopy() {
        return cloneCopy;
    }

    public void setCloneCopy(boolean cloneCopy) {
        this.cloneCopy = cloneCopy;
    }

    public void setAsyncMirrorTarget(boolean asyncMirrorTarget) {
        this.asyncMirrorTarget = asyncMirrorTarget;
    }

    public void setAsyncMirrorSource(boolean asyncMirrorSource) {
        this.asyncMirrorSource = asyncMirrorSource;
    }

    private boolean asyncMirrorTarget;
    private boolean asyncMirrorSource;

    @Override
    public void setVolumeCopyTarget(boolean v) {
        this.volumeCopyTarget = v;
    }

    @Override
    public void setVolumeCopySource(boolean v) {
        this.volumeCopySource = v;
    }

    @Override
    public void setOnlineVolumeCopy(boolean c) {
        this.cloneCopy = c;
    }

    @Override
    public void setPitBaseVolume(boolean v) {
        this.pitBaseVolume = v;
    }

    @Override
    public boolean isVolumeCopyTarget() {
        return volumeCopyTarget;
    }

    @Override
    public boolean isVolumeCopySource() {
        return volumeCopySource;
    }

    @Override
    public boolean isPitBaseVolume() {
        return pitBaseVolume;
    }

    @Override
    public boolean isOnlineVolumeCopy() {
        return cloneCopy;
    }

    /**
     * @API_Spec_Description True if the volume is a source in an Asynchronous Mirror relationship.
     */
    @Override
    public boolean isAsyncMirrorSource() {
        return asyncMirrorSource;  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * @API_Spec_Description True if the volume is a target in an Asynchronous Mirror relationship.
     */
    @Override
    public boolean isAsyncMirrorTarget() {
        return asyncMirrorTarget;  //To change body of implemented methods use File | Settings | File Templates.
    }

    private ProtectionType protectionType = ProtectionType.__UNDEFINED;

    /**
    * @API_Spec_Description This field provides the protection type for the volume.
    **/
    public ProtectionType getProtectionType() {
        return this.protectionType;
    }

    /**
     * @API_Spec_Description This field provides the protection type for the volume.
     **/
    public void setProtectionType(ProtectionType x) {
        this.protectionType = x;
    }

    private boolean remoteMirrorSource;

    @Override
    public void setRemoteMirrorTarget(boolean remoteMirrorTarget) {
        this.remoteMirrorTarget = remoteMirrorTarget;
    }

    @Override
    @ApiModelProperty("True if the volume is a source (primary), in an Remote Volume Mirror relationship.")
    public boolean isRemoteMirrorSource() {
        return this.remoteMirrorSource;
    }

    @Override
    @ApiModelProperty("True if the volume is a target (secondary), in an Remote Volume Mirror relationship.")
    public boolean isRemoteMirrorTarget() {
        return this.remoteMirrorTarget;
    }

    @Override
    public void setRemoteMirrorSource(boolean remoteMirrorSource) {
        this.remoteMirrorSource = remoteMirrorSource;
    }

    private boolean remoteMirrorTarget;

}
