package devmgr.api.model;

import io.swagger.annotations.ApiModelProperty;

import devmgr.api.symbol.LUNMapping;
import devmgr.api.symbol.ThinVolume;
import devmgr.api.symbol.VolumeCache;
import devmgr.api.symbol.VolumeMediaScanParams;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import java.util.ArrayList;
import java.util.List;

/**
 * Created with IntelliJ IDEA.
 * User: lorenp
 * Date: 1/7/14
 * Time: 1:40 PM
 * To change this template use File | Settings | File Templates.
 */
@XmlRootElement
public class ThinVolumeEx extends ThinVolume implements UserVolume, CopyableObject {
    private List<LUNMapping> mappings = new ArrayList<>();
    private boolean volumeFull;
    private String volumeGroupRef;

    @Override
    public int getBlkSize() {
        return blkSize;
    }

    public void setBlkSize(int blkSize) {
        this.blkSize = blkSize;
    }

    private int blkSize;

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof ThinVolumeEx)) {
            return false;
        }

        ThinVolumeEx thinVolume = (ThinVolumeEx) o;

        if (!getVolumeRef().equals(thinVolume.getVolumeRef())) {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode() {
        return getVolumeRef().hashCode();
    }

    @Override
    public boolean isDiskPool() {
        return true;
    }

    /**
     * The underlying volume type of the MappableObject
     *
     * @return
     */
    @Override
    public ObjectType getObjectType() {
        return ObjectType.thinVolume;
    }

    /**
     * Reference to the storage repository for the thin volume.
     * @return
     */
    public String getStorageVolumeRef() {
        return storageVolumeRef;
    }

    public void setStorageVolumeRef(String storageVolumeRef) {
        this.storageVolumeRef = storageVolumeRef;
    }

    /**
     * The repository volume that provides the storage for the thin volume
     * @see devmgr.api.model.VolumeEx
     */
    private String storageVolumeRef;

    /**
     * Id of the owning VolumeGroup.
     * @return
     */
    public String getVolumeGroupRef() {
        return volumeGroupRef;
    }

    @Override
    public int getSegmentSize() {
        return 131_072;
    }

    public void setVolumeGroupRef(String volumeGroupRef) {
        this.volumeGroupRef = volumeGroupRef;
    }

    /**
     * "True" if the ThinVolume repository is full.
     * @return
     */
    public boolean isVolumeFull() {
        return volumeFull;
    }

    public void setVolumeFull(boolean volumeFull) {
        this.volumeFull = volumeFull;
    }
    @Override
    public void setMappings(List<LUNMapping> mappings) {
        this.mappings=mappings;
    }

    /**
     * Returns the Id/Ref for the object
     *
     * @return
     */
    @Override
    public String getId() {
        return getVolumeRef();
    }

    /**
     * The world-wide name of the volume.
     */
    @Override
    public String getWwn() {
        return getWorldWideName();
    }

    /**
     * The user-assigned label of the volume.
     */
    @Override
    public String getName() {
        return getLabel();
    }

    /**
     * The storage capacity of the volume.
     */
    @Override
    public Long getTotalSizeInBytes() {
        return getCapacity();
    }

    /**
     * The set of Host-to-Volume LUN number mappings.
     */
    @Override
    public List<LUNMapping> getListOfMappings() {
        return mappings;
    }

    /**
     * Set to "true" when the volume has a valid mapping.
     */
    @Override
    public boolean isMapped() {
        return mappings.size() > 0;
    }

    public void setMapping(LUNMapping mapping) {
        this.mappings.add(mapping);
    }

    public void clearMappings() {
        this.mappings = new ArrayList<>();
    }

    /**
     * The reference value of the controller that currently owns (i.e. manages)
     * the volume. In non-Auto Volume Transfer (non-AVT) mode, host I/O access to the blocks in this
     * volume is permitted only through the controller that is the current owner. In AVT mode, an
     * I/O access to the controller that is not the current owner causes it to automatically become
     * the current owner.
     */
    @Override
    public String getCurrentControllerId() {
        return getCurrentManager();
    }

    /**
     * The identifier of the controller that is the preferred owner of the
     * volume. The preferred owner is tracked independent of the current owner, since the current owner
     * may be switched dynamically as a result of host-based multi-path transitions. Later, when the
     * error conditions that cause a multi-path transition have been corrected it is still possible
     * to determine the preferred owner and switch ownership back to it.
     */
    @Override
    public String getPreferredControllerId() {
        return getPreferredManager();
    }

    private boolean volumeCopyTarget;
    private boolean cloneCopy;
    private boolean volumeCopySource;
    private boolean pitBaseVolume;
    private boolean asyncMirrorTarget;
    private boolean asyncMirrorSource;

    @Override
    public void setVolumeCopyTarget(boolean v) {
        this.volumeCopyTarget = v;
    }

    @Override
    public void setVolumeCopySource(boolean v) {
        this.volumeCopySource = v;
    }

    @Override
    public void setOnlineVolumeCopy(boolean c) {
        this.cloneCopy = c;
    }

    @Override
    public void setPitBaseVolume(boolean v) {
        this.pitBaseVolume = v;
    }

    @Override
    public boolean isVolumeCopyTarget() {
        return volumeCopyTarget;
    }

    @Override
    public boolean isVolumeCopySource() {
        return volumeCopySource;
    }

    @Override
    public boolean isPitBaseVolume() {
        return pitBaseVolume;
    }

    @Override
    public boolean isOnlineVolumeCopy() {
        return cloneCopy;
    }

    /**
     * @API_Spec_Description True if the volume is a source in an Asynchronous Mirror relationship.
     */
    @Override
    public boolean isAsyncMirrorSource() {
        return asyncMirrorSource;  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * @API_Spec_Description True if the volume is a target in an Asynchronous Mirror relationship.
     */
    @Override
    public boolean isAsyncMirrorTarget() {
        return asyncMirrorTarget;  //To change body of implemented methods use File | Settings | File Templates.
    }

    /**
     * @API_Spec_Description Set to true if this volume is local in an AMG that is secondary.
     */
    @Override
    public void setAsyncMirrorTarget(boolean v) {
        this.asyncMirrorTarget = v;
    }

    /**
     * @API_Spec_Description Set to true if this volume is local in an AMG that is primary.
     */
    @Override
    public void setAsyncMirrorSource(boolean v) {
        this.asyncMirrorSource = v;
    }

    private boolean remoteMirrorSource;

    @Override
    public void setRemoteMirrorTarget(boolean remoteMirrorTarget) {
        this.remoteMirrorTarget = remoteMirrorTarget;
    }

    @Override
    @ApiModelProperty("True if the volume is a source (primary), in an Remote Volume Mirror relationship.")
    public boolean isRemoteMirrorSource() {
        return this.remoteMirrorSource;
    }

    @Override
    @ApiModelProperty("True if the volume is a target (secondary), in an Remote Volume Mirror relationship.")
    public boolean isRemoteMirrorTarget() {
        return this.remoteMirrorTarget;
    }

    @Override
    public void setRemoteMirrorSource(boolean remoteMirrorSource) {
        this.remoteMirrorSource = remoteMirrorSource;
    }

    @Override
    public VolumeCache getCacheSettings() {
        return getVolumeCache();
    }

    private boolean remoteMirrorTarget;

    @Override
    @ApiModelProperty("True if this volume is added to a flashCache.")
    public boolean isFlashCached() {
        return flashCached;
    }

    public void setFlashCached(boolean flashCached) {
        this.flashCached = flashCached;
    }

    private boolean flashCached;

	/** The volume-specific media scan settings currently in effect for the volume. */
	private VolumeMediaScanParams mediaScan;

	/** @return The volume-specific media scan settings currently in effect for the volume. */
	public VolumeMediaScanParams getMediaScan() {
		return this.mediaScan;
	}
	
	/** @param x The volume-specific media scan settings currently in effect for the volume. */
	public void setMediaScan(VolumeMediaScanParams x) {
		this.mediaScan = x;
	}

    @ApiModelProperty(value = "Metadata associated with the volume")
    private List<VolumeMetadataItem> metadata=new ArrayList<>();

    @Override
    public List<VolumeMetadataItem> getMetadata() {
        return metadata;
    }

    @Override
    public boolean isThinProvisioned() {
        return true;
    }


    public void setDataAssurance(boolean dataAssurance) {
        this.dataAssurance = dataAssurance;
    }

    private boolean dataAssurance;

    @Override
    public boolean isDataAssurance() {
        return this.dataAssurance;
    }

    public void setMetadata(List<VolumeMetadataItem> metadata) {
        this.metadata = metadata;
    }
}
