package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure represents a cluster of host systems that shares one or more LUN-to-volume mappings for accessing the storage array via the I/O path. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(796)
public class Cluster implements Serializable,devmgr.api.model.Identifiable,devmgr.api.model.Named {
	public Cluster() {
	}

	/** The unique identification value for this object. Other objects may use this reference value to refer to the cluster. */
	@io.swagger.annotations.ApiModelProperty(value ="The unique identification value for this object. Other objects may use this reference value to refer to the cluster." , required = true)
	@XmlElement(required = true)
	private String clusterRef;

	/** @return The unique identification value for this object. Other objects may use this reference value to refer to the cluster. */
	public String getClusterRef() {
		return this.clusterRef;
	}
	/** @param x The unique identification value for this object. Other objects may use this reference value to refer to the cluster. */
	public void setClusterRef(String x) {
		this.clusterRef = x;
	}

	/** The user-assigned, descriptive label string for the cluster. */
	@io.swagger.annotations.ApiModelProperty(value ="The user-assigned, descriptive label string for the cluster." , required = true)
	@XmlElement(required = true)
	private String label;

	/** @return The user-assigned, descriptive label string for the cluster. */
	public String getLabel() {
		return this.label;
	}
	/** @param x The user-assigned, descriptive label string for the cluster. */
	public void setLabel(String x) {
		this.label = x;
	}

	/** If true, indicates that I/O accesses from this cluster are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the cluster are subject to cluster-specific LUN-to-volume mappings. */
	@io.swagger.annotations.ApiModelProperty(value ="If true, indicates that I/O accesses from this cluster are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the cluster are subject to cluster-specific LUN-to-volume mappings." , required = true)
	@XmlElement(required = true)
	private boolean isSAControlled;

	/** @return If true, indicates that I/O accesses from this cluster are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the cluster are subject to cluster-specific LUN-to-volume mappings. */
	public boolean isIsSAControlled() {
		return this.isSAControlled;
	}
	/** @param x If true, indicates that I/O accesses from this cluster are subject to the storage array's default LUN-to-volume mappings. If false, indicates that I/O accesses from the cluster are subject to cluster-specific LUN-to-volume mappings. */
	public void setIsSAControlled(boolean x) {
		this.isSAControlled = x;
	}

	/** If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other clusters, in addition to this one. */
	@io.swagger.annotations.ApiModelProperty(value ="If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other clusters, in addition to this one." , required = true)
	@XmlElement(required = true)
	private boolean confirmLUNMappingCreation;

	/** @return If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other clusters, in addition to this one. */
	public boolean isConfirmLUNMappingCreation() {
		return this.confirmLUNMappingCreation;
	}
	/** @param x If true, indicates that creation of LUN-to-volume mappings should require careful confirmation from the end-user, since such a mapping will alter the volume access rights of other clusters, in addition to this one. */
	public void setConfirmLUNMappingCreation(boolean x) {
		this.confirmLUNMappingCreation = x;
	}

	/** This field is true if the host has a PI capable access method. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is true if the host has a PI capable access method." , required = true)
	@XmlElement(required = true)
	private boolean protectionInformationCapableAccessMethod;

	/** @return This field is true if the host has a PI capable access method. */
	public boolean isProtectionInformationCapableAccessMethod() {
		return this.protectionInformationCapableAccessMethod;
	}
	/** @param x This field is true if the host has a PI capable access method. */
	public void setProtectionInformationCapableAccessMethod(boolean x) {
		this.protectionInformationCapableAccessMethod = x;
	}
	@Override
	public String getId(){
		return clusterRef;
	}
	@Override
	public String getName(){
		return label;
	}
}
