package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This union type contains one of several different types of counter groups that was collected by an individual controller. A counter group is an aggregate of related counter statistics. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(885)
public class CounterGroup implements Serializable {
	public CounterGroup() {
	}

	/** This enumeration type identifies the different types of counter group statistics that are provided by the controller firmware. */
	@io.swagger.annotations.ApiModelProperty(value ="This enumeration type identifies the different types of counter group statistics that are provided by the controller firmware." , required = true)
	@XmlElement(required = true)
	private CounterGroupType groupType = CounterGroupType.__UNDEFINED;

	/** @return This enumeration type identifies the different types of counter group statistics that are provided by the controller firmware. */
	public CounterGroupType getGroupType() {
		return this.groupType;
	}
	/** @param x This enumeration type identifies the different types of counter group statistics that are provided by the controller firmware. */
	public void setGroupType(CounterGroupType x) {
		this.groupType = x;
	}

	/** Drive-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_DRIVE. */
	@io.swagger.annotations.ApiModelProperty(value ="Drive-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_DRIVE." , required = false)
	@XmlElement(required = false)
	private DriveCounterGroup drvCounterGroup;

	/** @return Drive-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_DRIVE. */
	public DriveCounterGroup getDrvCounterGroup() {
		return this.drvCounterGroup;
	}
	/** @param x Drive-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_DRIVE. */
	public void setDrvCounterGroup(DriveCounterGroup x) {
		this.drvCounterGroup = x;
	}

	/** RAID-implementation-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_IMPLEMENTATION. */
	@io.swagger.annotations.ApiModelProperty(value ="RAID-implementation-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_IMPLEMENTATION." , required = false)
	@XmlElement(required = false)
	private ImplementationCounterGroup implCounterGroup;

	/** @return RAID-implementation-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_IMPLEMENTATION. */
	public ImplementationCounterGroup getImplCounterGroup() {
		return this.implCounterGroup;
	}
	/** @param x RAID-implementation-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_IMPLEMENTATION. */
	public void setImplCounterGroup(ImplementationCounterGroup x) {
		this.implCounterGroup = x;
	}

	/** I/O-operation-related statistical counters. This field is only present if the groupType is equal to COUNTER_GROUP_IO */
	@io.swagger.annotations.ApiModelProperty(value ="I/O-operation-related statistical counters. This field is only present if the groupType is equal to COUNTER_GROUP_IO" , required = false)
	@XmlElement(required = false)
	private IoCounterGroup ioCounterGroup;

	/** @return I/O-operation-related statistical counters. This field is only present if the groupType is equal to COUNTER_GROUP_IO */
	public IoCounterGroup getIoCounterGroup() {
		return this.ioCounterGroup;
	}
	/** @param x I/O-operation-related statistical counters. This field is only present if the groupType is equal to COUNTER_GROUP_IO */
	public void setIoCounterGroup(IoCounterGroup x) {
		this.ioCounterGroup = x;
	}

	/** Volume-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_VOLUME. */
	@io.swagger.annotations.ApiModelProperty(value ="Volume-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_VOLUME." , required = false)
	@XmlElement(required = false)
	private VolumeCounterGroup volCounterGroup;

	/** @return Volume-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_VOLUME. */
	public VolumeCounterGroup getVolCounterGroup() {
		return this.volCounterGroup;
	}
	/** @param x Volume-related statistical counters. This field is only present if groupType is equal to COUNTER_GROUP_VOLUME. */
	public void setVolCounterGroup(VolumeCounterGroup x) {
		this.volCounterGroup = x;
	}

	/** The ControllerCounterGroup tracks statistics at the controller level and are not specific to a volume, interface or drive. These fields include the CPU utilization, total numbers of reads, writes, and non-read/write commands, and cache mirroring statistics. The ObjectReference must be a ControllerRef. */
	@io.swagger.annotations.ApiModelProperty(value ="The ControllerCounterGroup tracks statistics at the controller level and are not specific to a volume, interface or drive. These fields include the CPU utilization, total numbers of reads, writes, and non-read/write commands, and cache mirroring statistics. The ObjectReference must be a ControllerRef." , required = false)
	@XmlElement(required = false)
	private ControllerCounterGroup controllerCounterGroup;

	/** @return The ControllerCounterGroup tracks statistics at the controller level and are not specific to a volume, interface or drive. These fields include the CPU utilization, total numbers of reads, writes, and non-read/write commands, and cache mirroring statistics. The ObjectReference must be a ControllerRef. */
	public ControllerCounterGroup getControllerCounterGroup() {
		return this.controllerCounterGroup;
	}
	/** @param x The ControllerCounterGroup tracks statistics at the controller level and are not specific to a volume, interface or drive. These fields include the CPU utilization, total numbers of reads, writes, and non-read/write commands, and cache mirroring statistics. The ObjectReference must be a ControllerRef. */
	public void setControllerCounterGroup(ControllerCounterGroup x) {
		this.controllerCounterGroup = x;
	}

	/** The InterfaceCounterGroup tracks statistics on a per channel level. This group reports the type of channel, its channel number, and the read, write and other operation counters. It also reports queue depth statistics. */
	@io.swagger.annotations.ApiModelProperty(value ="The InterfaceCounterGroup tracks statistics on a per channel level. This group reports the type of channel, its channel number, and the read, write and other operation counters. It also reports queue depth statistics." , required = false)
	@XmlElement(required = false)
	private InterfaceCounterGroup interfaceCounterGroup;

	/** @return The InterfaceCounterGroup tracks statistics on a per channel level. This group reports the type of channel, its channel number, and the read, write and other operation counters. It also reports queue depth statistics. */
	public InterfaceCounterGroup getInterfaceCounterGroup() {
		return this.interfaceCounterGroup;
	}
	/** @param x The InterfaceCounterGroup tracks statistics on a per channel level. This group reports the type of channel, its channel number, and the read, write and other operation counters. It also reports queue depth statistics. */
	public void setInterfaceCounterGroup(InterfaceCounterGroup x) {
		this.interfaceCounterGroup = x;
	}
}
