package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure provides information about a physical drive that is part of the storage array. One such object is reported for each drive in the information returned by the getObjectGraph operation. Note that missing drive objects exist for drives assigned to a group or hot spares - but not for unassigned drives. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(954)
public class Drive implements Serializable,devmgr.api.model.Identifiable {
	public Drive() {
	}

	/** True if the drive is in the offline state, false otherwise. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the drive is in the offline state, false otherwise. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private boolean offline;

	/** @return True if the drive is in the offline state, false otherwise. This field is valid for missing drives. */
	public boolean isOffline() {
		return this.offline;
	}
	/** @param x True if the drive is in the offline state, false otherwise. This field is valid for missing drives. */
	public void setOffline(boolean x) {
		this.offline = x;
	}

	/** True if the drive has been designated as a hot spare; false otherwise. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the drive has been designated as a hot spare; false otherwise. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private boolean hotSpare;

	/** @return True if the drive has been designated as a hot spare; false otherwise. This field is valid for missing drives. */
	public boolean isHotSpare() {
		return this.hotSpare;
	}
	/** @param x True if the drive has been designated as a hot spare; false otherwise. This field is valid for missing drives. */
	public void setHotSpare(boolean x) {
		this.hotSpare = x;
	}

	/** True if no drive information (serial #, capacity, etc.) can be obtained. This field is always true for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="True if no drive information (serial #, capacity, etc.) can be obtained. This field is always true for missing drives." , required = true)
	@XmlElement(required = true)
	private boolean invalidDriveData;

	/** @return True if no drive information (serial #, capacity, etc.) can be obtained. This field is always true for missing drives. */
	public boolean isInvalidDriveData() {
		return this.invalidDriveData;
	}
	/** @param x True if no drive information (serial #, capacity, etc.) can be obtained. This field is always true for missing drives. */
	public void setInvalidDriveData(boolean x) {
		this.invalidDriveData = x;
	}

	/** True if the drive is available for use in creating a new volume group; false otherwise. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the drive is available for use in creating a new volume group; false otherwise. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private boolean available;

	/** @return True if the drive is available for use in creating a new volume group; false otherwise. This field is valid for missing drives. */
	public boolean isAvailable() {
		return this.available;
	}
	/** @param x True if the drive is available for use in creating a new volume group; false otherwise. This field is valid for missing drives. */
	public void setAvailable(boolean x) {
		this.available = x;
	}

	/** True if the drive is drive Predicted Failure analysis predicts a drive failure. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the drive is drive Predicted Failure analysis predicts a drive failure. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private boolean pfa;

	/** @return True if the drive is drive Predicted Failure analysis predicts a drive failure. This field is valid for missing drives. */
	public boolean isPfa() {
		return this.pfa;
	}
	/** @param x True if the drive is drive Predicted Failure analysis predicts a drive failure. This field is valid for missing drives. */
	public void setPfa(boolean x) {
		this.pfa = x;
	}

	/** The identifier value for this drive. Other objects may use this reference value to refer to the drive. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The identifier value for this drive. Other objects may use this reference value to refer to the drive. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private String driveRef;

	/** @return The identifier value for this drive. Other objects may use this reference value to refer to the drive. This field is valid for missing drives. */
	public String getDriveRef() {
		return this.driveRef;
	}
	/** @param x The identifier value for this drive. Other objects may use this reference value to refer to the drive. This field is valid for missing drives. */
	public void setDriveRef(String x) {
		this.driveRef = x;
	}

	/** An indication of the current status of the drive. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of the current status of the drive. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private DriveStatus status = DriveStatus.__UNDEFINED;

	/** @return An indication of the current status of the drive. This field is valid for missing drives. */
	public DriveStatus getStatus() {
		return this.status;
	}
	/** @param x An indication of the current status of the drive. This field is valid for missing drives. */
	public void setStatus(DriveStatus x) {
		this.status = x;
	}

	/** An indication of the reason for the current status of the drive. This field is most useful when the current status is something other than optimal; it identifies the event that caused the status to change to its current value. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of the reason for the current status of the drive. This field is most useful when the current status is something other than optimal; it identifies the event that caused the status to change to its current value. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private DriveStatusCause cause = DriveStatusCause.__UNDEFINED;

	/** @return An indication of the reason for the current status of the drive. This field is most useful when the current status is something other than optimal; it identifies the event that caused the status to change to its current value. This field is valid for missing drives. */
	public DriveStatusCause getCause() {
		return this.cause;
	}
	/** @param x An indication of the reason for the current status of the drive. This field is most useful when the current status is something other than optimal; it identifies the event that caused the status to change to its current value. This field is valid for missing drives. */
	public void setCause(DriveStatusCause x) {
		this.cause = x;
	}

	/** Information about the I/O interface between the controller and the drive. For example, for a SCSI-attached drive, this field will contain information about the drive's channel and SCSI ID values. For other interface types, different data will be available in this field. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about the I/O interface between the controller and the drive. For example, for a SCSI-attached drive, this field will contain information about the drive's channel and SCSI ID values. For other interface types, different data will be available in this field." , required = true)
	@XmlElement(required = true)
	private DriveTypeData interfaceType;

	/** @return Information about the I/O interface between the controller and the drive. For example, for a SCSI-attached drive, this field will contain information about the drive's channel and SCSI ID values. For other interface types, different data will be available in this field. */
	public DriveTypeData getInterfaceType() {
		return this.interfaceType;
	}
	/** @param x Information about the I/O interface between the controller and the drive. For example, for a SCSI-attached drive, this field will contain information about the drive's channel and SCSI ID values. For other interface types, different data will be available in this field. */
	public void setInterfaceType(DriveTypeData x) {
		this.interfaceType = x;
	}

	/** The physical location of the drive. Beginning with the Allegheny release, the parent reference in Location identifies the tray or drawer containing the drive, and the position field is the parent-relative/like-component relative slot number of the drive, starting at 1. For missing drives this field contains the last known location. */
	@io.swagger.annotations.ApiModelProperty(value ="The physical location of the drive. Beginning with the Allegheny release, the parent reference in Location identifies the tray or drawer containing the drive, and the position field is the parent-relative/like-component relative slot number of the drive, starting at 1. For missing drives this field contains the last known location." , required = true)
	@XmlElement(required = true)
	private Location physicalLocation;

	/** @return The physical location of the drive. Beginning with the Allegheny release, the parent reference in Location identifies the tray or drawer containing the drive, and the position field is the parent-relative/like-component relative slot number of the drive, starting at 1. For missing drives this field contains the last known location. */
	public Location getPhysicalLocation() {
		return this.physicalLocation;
	}
	/** @param x The physical location of the drive. Beginning with the Allegheny release, the parent reference in Location identifies the tray or drawer containing the drive, and the position field is the parent-relative/like-component relative slot number of the drive, starting at 1. For missing drives this field contains the last known location. */
	public void setPhysicalLocation(Location x) {
		this.physicalLocation = x;
	}

	/** The variable-length ASCII text string that identifies the drive manufacturer. Note that this information is not returned for most Serial ATA (SATA) drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The variable-length ASCII text string that identifies the drive manufacturer. Note that this information is not returned for most Serial ATA (SATA) drives." , required = true)
	@XmlElement(required = true)
	private String manufacturer;

	/** @return The variable-length ASCII text string that identifies the drive manufacturer. Note that this information is not returned for most Serial ATA (SATA) drives. */
	public String getManufacturer() {
		return this.manufacturer;
	}
	/** @param x The variable-length ASCII text string that identifies the drive manufacturer. Note that this information is not returned for most Serial ATA (SATA) drives. */
	public void setManufacturer(String x) {
		this.manufacturer = x;
	}

	/** The date of manufacture of the drive, represented in seconds since midnight GMT on January 1, 1970. Note that this information is not returned for most Serial ATA (SATA) drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The date of manufacture of the drive, represented in seconds since midnight GMT on January 1, 1970. Note that this information is not returned for most Serial ATA (SATA) drives." , required = true)
	@XmlElement(required = true)
	private long manufacturerDate;

	/** @return The date of manufacture of the drive, represented in seconds since midnight GMT on January 1, 1970. Note that this information is not returned for most Serial ATA (SATA) drives. */
	public long getManufacturerDate() {
		return this.manufacturerDate;
	}
	/** @param x The date of manufacture of the drive, represented in seconds since midnight GMT on January 1, 1970. Note that this information is not returned for most Serial ATA (SATA) drives. */
	public void setManufacturerDate(long x) {
		this.manufacturerDate = x;
	}

	/** The variable-length ASCII text string that identifies the product by name, as assigned by the manufacturer. */
	@io.swagger.annotations.ApiModelProperty(value ="The variable-length ASCII text string that identifies the product by name, as assigned by the manufacturer." , required = true)
	@XmlElement(required = true)
	private String productID;

	/** @return The variable-length ASCII text string that identifies the product by name, as assigned by the manufacturer. */
	public String getProductID() {
		return this.productID;
	}
	/** @param x The variable-length ASCII text string that identifies the product by name, as assigned by the manufacturer. */
	public void setProductID(String x) {
		this.productID = x;
	}

	/** The variable-length ASCII text string for the serial number of the drive. */
	@io.swagger.annotations.ApiModelProperty(value ="The variable-length ASCII text string for the serial number of the drive." , required = true)
	@XmlElement(required = true)
	private String serialNumber;

	/** @return The variable-length ASCII text string for the serial number of the drive. */
	public String getSerialNumber() {
		return this.serialNumber;
	}
	/** @param x The variable-length ASCII text string for the serial number of the drive. */
	public void setSerialNumber(String x) {
		this.serialNumber = x;
	}

	/** This data is a variable-length ASCII text string. If an interposer is present in front of SATA drives, the string identifies the version of the interposer package. In this case, the SATA drive firmware version can be found in the physicalDriveTypeData field. If an interposer is not present (always the case for Fibre Channel drives) this field describes the drive firmware version. */
	@io.swagger.annotations.ApiModelProperty(value ="This data is a variable-length ASCII text string. If an interposer is present in front of SATA drives, the string identifies the version of the interposer package. In this case, the SATA drive firmware version can be found in the physicalDriveTypeData field. If an interposer is not present (always the case for Fibre Channel drives) this field describes the drive firmware version." , required = true)
	@XmlElement(required = true)
	private String softwareVersion;

	/** @return This data is a variable-length ASCII text string. If an interposer is present in front of SATA drives, the string identifies the version of the interposer package. In this case, the SATA drive firmware version can be found in the physicalDriveTypeData field. If an interposer is not present (always the case for Fibre Channel drives) this field describes the drive firmware version. */
	public String getSoftwareVersion() {
		return this.softwareVersion;
	}
	/** @param x This data is a variable-length ASCII text string. If an interposer is present in front of SATA drives, the string identifies the version of the interposer package. In this case, the SATA drive firmware version can be found in the physicalDriveTypeData field. If an interposer is not present (always the case for Fibre Channel drives) this field describes the drive firmware version. */
	public void setSoftwareVersion(String x) {
		this.softwareVersion = x;
	}

	/** The block (i.e. sector) size used by the drive, represented in bytes. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The block (i.e. sector) size used by the drive, represented in bytes. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private int blkSize;

	/** @return The block (i.e. sector) size used by the drive, represented in bytes. This field is valid for missing drives. */
	public int getBlkSize() {
		return this.blkSize;
	}
	/** @param x The block (i.e. sector) size used by the drive, represented in bytes. This field is valid for missing drives. */
	public void setBlkSize(int x) {
		this.blkSize = x;
	}

	/** The usable capacity of the drive, in bytes, after accounting for any space that is reserved for use by the array controller for overhead information. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The usable capacity of the drive, in bytes, after accounting for any space that is reserved for use by the array controller for overhead information. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private long usableCapacity;

	/** @return The usable capacity of the drive, in bytes, after accounting for any space that is reserved for use by the array controller for overhead information. This field is valid for missing drives. */
	public long getUsableCapacity() {
		return this.usableCapacity;
	}
	/** @param x The usable capacity of the drive, in bytes, after accounting for any space that is reserved for use by the array controller for overhead information. This field is valid for missing drives. */
	public void setUsableCapacity(long x) {
		this.usableCapacity = x;
	}

	/** The raw capacity of the drive, in bytes. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The raw capacity of the drive, in bytes. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private long rawCapacity;

	/** @return The raw capacity of the drive, in bytes. This field is valid for missing drives. */
	public long getRawCapacity() {
		return this.rawCapacity;
	}
	/** @param x The raw capacity of the drive, in bytes. This field is valid for missing drives. */
	public void setRawCapacity(long x) {
		this.rawCapacity = x;
	}

	/** A variable-length, opaque field that contains the drive's world-wide name, or globally unique identifier value. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length, opaque field that contains the drive's world-wide name, or globally unique identifier value. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private String worldWideName;

	/** @return A variable-length, opaque field that contains the drive's world-wide name, or globally unique identifier value. This field is valid for missing drives. */
	public String getWorldWideName() {
		return this.worldWideName;
	}
	/** @param x A variable-length, opaque field that contains the drive's world-wide name, or globally unique identifier value. This field is valid for missing drives. */
	public void setWorldWideName(String x) {
		this.worldWideName = x;
	}

	/** The reference value of the volume group, disk pool, or flash cache to which this drive is currently assigned. If a hot spare drive is actively sparing for a failed drive, this field will identify the volume group, disk pool, or flash cache that is using the hot spare drive. If the drive is not currently assigned, or is an idle hot spare, the reference value will be null. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The reference value of the volume group, disk pool, or flash cache to which this drive is currently assigned. If a hot spare drive is actively sparing for a failed drive, this field will identify the volume group, disk pool, or flash cache that is using the hot spare drive. If the drive is not currently assigned, or is an idle hot spare, the reference value will be null. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private String currentVolumeGroupRef;

	/** @return The reference value of the volume group, disk pool, or flash cache to which this drive is currently assigned. If a hot spare drive is actively sparing for a failed drive, this field will identify the volume group, disk pool, or flash cache that is using the hot spare drive. If the drive is not currently assigned, or is an idle hot spare, the reference value will be null. This field is valid for missing drives. */
	public String getCurrentVolumeGroupRef() {
		return this.currentVolumeGroupRef;
	}
	/** @param x The reference value of the volume group, disk pool, or flash cache to which this drive is currently assigned. If a hot spare drive is actively sparing for a failed drive, this field will identify the volume group, disk pool, or flash cache that is using the hot spare drive. If the drive is not currently assigned, or is an idle hot spare, the reference value will be null. This field is valid for missing drives. */
	public void setCurrentVolumeGroupRef(String x) {
		this.currentVolumeGroupRef = x;
	}

	/** The reference value of the drive for which this drive is acting as a hot spare. This field is only used if the Drive object represents a global hot spare that is actively sparing for a failed drive. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The reference value of the drive for which this drive is acting as a hot spare. This field is only used if the Drive object represents a global hot spare that is actively sparing for a failed drive. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private String sparedForDriveRef;

	/** @return The reference value of the drive for which this drive is acting as a hot spare. This field is only used if the Drive object represents a global hot spare that is actively sparing for a failed drive. This field is valid for missing drives. */
	public String getSparedForDriveRef() {
		return this.sparedForDriveRef;
	}
	/** @param x The reference value of the drive for which this drive is acting as a hot spare. This field is only used if the Drive object represents a global hot spare that is actively sparing for a failed drive. This field is valid for missing drives. */
	public void setSparedForDriveRef(String x) {
		this.sparedForDriveRef = x;
	}

	/** This field is only used if the Drive object represents a drive that is part of a RAID-1 volume group. It identifies the drive that is tied to this one for RAID-1 mirroring operations. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is only used if the Drive object represents a drive that is part of a RAID-1 volume group. It identifies the drive that is tied to this one for RAID-1 mirroring operations. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private String mirrorDrive;

	/** @return This field is only used if the Drive object represents a drive that is part of a RAID-1 volume group. It identifies the drive that is tied to this one for RAID-1 mirroring operations. This field is valid for missing drives. */
	public String getMirrorDrive() {
		return this.mirrorDrive;
	}
	/** @param x This field is only used if the Drive object represents a drive that is part of a RAID-1 volume group. It identifies the drive that is tied to this one for RAID-1 mirroring operations. This field is valid for missing drives. */
	public void setMirrorDrive(String x) {
		this.mirrorDrive = x;
	}

	/** True if the drive does not have redundant access. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the drive does not have redundant access." , required = true)
	@XmlElement(required = true)
	private boolean nonRedundantAccess;

	/** @return True if the drive does not have redundant access. */
	public boolean isNonRedundantAccess() {
		return this.nonRedundantAccess;
	}
	/** @param x True if the drive does not have redundant access. */
	public void setNonRedundantAccess(boolean x) {
		this.nonRedundantAccess = x;
	}

	/** The channel to the tray that is still operational (if nonRedundantAccess is True). */
	@io.swagger.annotations.ApiModelProperty(value ="The channel to the tray that is still operational (if nonRedundantAccess is True)." , required = true)
	@XmlElement(required = true)
	private int workingChannel;

	/** @return The channel to the tray that is still operational (if nonRedundantAccess is True). */
	public int getWorkingChannel() {
		return this.workingChannel;
	}
	/** @param x The channel to the tray that is still operational (if nonRedundantAccess is True). */
	public void setWorkingChannel(int x) {
		this.workingChannel = x;
	}

	/** The volume group index. This is the zero-relative position of the drive with respect to the stripe-ordering for the volume group. A value of -1 indicates that the drive does not belong to any group. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The volume group index. This is the zero-relative position of the drive with respect to the stripe-ordering for the volume group. A value of -1 indicates that the drive does not belong to any group. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private int volumeGroupIndex;

	/** @return The volume group index. This is the zero-relative position of the drive with respect to the stripe-ordering for the volume group. A value of -1 indicates that the drive does not belong to any group. This field is valid for missing drives. */
	public int getVolumeGroupIndex() {
		return this.volumeGroupIndex;
	}
	/** @param x The volume group index. This is the zero-relative position of the drive with respect to the stripe-ordering for the volume group. A value of -1 indicates that the drive does not belong to any group. This field is valid for missing drives. */
	public void setVolumeGroupIndex(int x) {
		this.volumeGroupIndex = x;
	}

	/** The speed of the drive. Will be unknown for a SCSI drive. */
	@io.swagger.annotations.ApiModelProperty(value ="The speed of the drive. Will be unknown for a SCSI drive." , required = true)
	@XmlElement(required = true)
	private InterfaceSpeed currentSpeed = InterfaceSpeed.__UNDEFINED;

	/** @return The speed of the drive. Will be unknown for a SCSI drive. */
	public InterfaceSpeed getCurrentSpeed() {
		return this.currentSpeed;
	}
	/** @param x The speed of the drive. Will be unknown for a SCSI drive. */
	public void setCurrentSpeed(InterfaceSpeed x) {
		this.currentSpeed = x;
	}

	/** The maximum speed of the drive. Currently not used. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum speed of the drive. Currently not used." , required = true)
	@XmlElement(required = true)
	private InterfaceSpeed maxSpeed = InterfaceSpeed.__UNDEFINED;

	/** @return The maximum speed of the drive. Currently not used. */
	public InterfaceSpeed getMaxSpeed() {
		return this.maxSpeed;
	}
	/** @param x The maximum speed of the drive. Currently not used. */
	public void setMaxSpeed(InterfaceSpeed x) {
		this.maxSpeed = x;
	}

	/** True, if the drive has the DR_UNCERTIFIED flag set. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="True, if the drive has the DR_UNCERTIFIED flag set. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private boolean uncertified;

	/** @return True, if the drive has the DR_UNCERTIFIED flag set. This field is valid for missing drives. */
	public boolean isUncertified() {
		return this.uncertified;
	}
	/** @param x True, if the drive has the DR_UNCERTIFIED flag set. This field is valid for missing drives. */
	public void setUncertified(boolean x) {
		this.uncertified = x;
	}

	/** True, if a path to this drive is degraded. */
	@io.swagger.annotations.ApiModelProperty(value ="True, if a path to this drive is degraded." , required = true)
	@XmlElement(required = true)
	private boolean hasDegradedChannel;

	/** @return True, if a path to this drive is degraded. */
	public boolean isHasDegradedChannel() {
		return this.hasDegradedChannel;
	}
	/** @param x True, if a path to this drive is degraded. */
	public void setHasDegradedChannel(boolean x) {
		this.hasDegradedChannel = x;
	}

	/** The IDs of degraded channels. */
	@io.swagger.annotations.ApiModelProperty(value ="The IDs of degraded channels." , required = true)
	@XmlElement(required = true)
	private int[] degradedChannels;

	/** @return The IDs of degraded channels. */
	public int[] getDegradedChannels() {
		return this.degradedChannels;
	}
	/** @param x The IDs of degraded channels. */
	public void setDegradedChannels(int[] x) {
		this.degradedChannels = x;
	}

	/** The physical drive type. */
	@io.swagger.annotations.ApiModelProperty(value ="The physical drive type." , required = true)
	@XmlElement(required = true)
	private PhysicalDriveType phyDriveType = PhysicalDriveType.__UNDEFINED;

	/** @return The physical drive type. */
	public PhysicalDriveType getPhyDriveType() {
		return this.phyDriveType;
	}
	/** @param x The physical drive type. */
	public void setPhyDriveType(PhysicalDriveType x) {
		this.phyDriveType = x;
	}

	/** The drive reported spindle speed. Solid State Disk (SSD) drives report zero. */
	@io.swagger.annotations.ApiModelProperty(value ="The drive reported spindle speed. Solid State Disk (SSD) drives report zero." , required = true)
	@XmlElement(required = true)
	private int spindleSpeed;

	/** @return The drive reported spindle speed. Solid State Disk (SSD) drives report zero. */
	public int getSpindleSpeed() {
		return this.spindleSpeed;
	}
	/** @param x The drive reported spindle speed. Solid State Disk (SSD) drives report zero. */
	public void setSpindleSpeed(int x) {
		this.spindleSpeed = x;
	}

	/** The CRU type of the drive plus its ready-to-remove attributes, which are based on the CRU type. */
	@io.swagger.annotations.ApiModelProperty(value ="The CRU type of the drive plus its ready-to-remove attributes, which are based on the CRU type." , required = true)
	@XmlElement(required = true)
	private RTRAttributes rtrAttributes;

	/** @return The CRU type of the drive plus its ready-to-remove attributes, which are based on the CRU type. */
	public RTRAttributes getRtrAttributes() {
		return this.rtrAttributes;
	}
	/** @param x The CRU type of the drive plus its ready-to-remove attributes, which are based on the CRU type. */
	public void setRtrAttributes(RTRAttributes x) {
		this.rtrAttributes = x;
	}

	/** reserved. */
	@io.swagger.annotations.ApiModelProperty(value ="reserved." , required = true)
	@XmlElement(required = true)
	private String reserved;

	/** @return reserved. */
	public String getReserved() {
		return this.reserved;
	}
	/** @param x reserved. */
	public void setReserved(String x) {
		this.reserved = x;
	}

	/** Information specific to a physical drive type. */
	@io.swagger.annotations.ApiModelProperty(value ="Information specific to a physical drive type." , required = true)
	@XmlElement(required = true)
	private PhysicalDriveTypeData phyDriveTypeData;

	/** @return Information specific to a physical drive type. */
	public PhysicalDriveTypeData getPhyDriveTypeData() {
		return this.phyDriveTypeData;
	}
	/** @param x Information specific to a physical drive type. */
	public void setPhyDriveTypeData(PhysicalDriveTypeData x) {
		this.phyDriveTypeData = x;
	}

	/** The reason a PFA condition has been raised for this drive. */
	@io.swagger.annotations.ApiModelProperty(value ="The reason a PFA condition has been raised for this drive." , required = true)
	@XmlElement(required = true)
	private DrivePfaReason pfaReason = DrivePfaReason.__UNDEFINED;

	/** @return The reason a PFA condition has been raised for this drive. */
	public DrivePfaReason getPfaReason() {
		return this.pfaReason;
	}
	/** @param x The reason a PFA condition has been raised for this drive. */
	public void setPfaReason(DrivePfaReason x) {
		this.pfaReason = x;
	}

	/** A list of object references where each reference identifies the source of a drive bypass condition. Possible referenced objects include the drive itself, a controller, or the ESM(s). When the bypass source is a controller or the drive, the list will typically hold just one reference; when the bypass source is the ESM(s), the list can hold up to two references, indicating either one or both ESMs. The list normally holds valid data whenever the drive is in the bypassed state (DRIVE_STAT_BYPASSED) , however it may be empty if the source of the bypass is unknown. It is also possible for the list to hold valid data when the drive is optimal, if only one ESM has bypassed the drive. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of object references where each reference identifies the source of a drive bypass condition. Possible referenced objects include the drive itself, a controller, or the ESM(s). When the bypass source is a controller or the drive, the list will typically hold just one reference; when the bypass source is the ESM(s), the list can hold up to two references, indicating either one or both ESMs. The list normally holds valid data whenever the drive is in the bypassed state (DRIVE_STAT_BYPASSED) , however it may be empty if the source of the bypass is unknown. It is also possible for the list to hold valid data when the drive is optimal, if only one ESM has bypassed the drive." , required = true)
	@XmlElement(required = true)
	private ObjectReference[] bypassSource;

	/** @return A list of object references where each reference identifies the source of a drive bypass condition. Possible referenced objects include the drive itself, a controller, or the ESM(s). When the bypass source is a controller or the drive, the list will typically hold just one reference; when the bypass source is the ESM(s), the list can hold up to two references, indicating either one or both ESMs. The list normally holds valid data whenever the drive is in the bypassed state (DRIVE_STAT_BYPASSED) , however it may be empty if the source of the bypass is unknown. It is also possible for the list to hold valid data when the drive is optimal, if only one ESM has bypassed the drive. */
	public ObjectReference[] getBypassSource() {
		return this.bypassSource;
	}
	/** @param x A list of object references where each reference identifies the source of a drive bypass condition. Possible referenced objects include the drive itself, a controller, or the ESM(s). When the bypass source is a controller or the drive, the list will typically hold just one reference; when the bypass source is the ESM(s), the list can hold up to two references, indicating either one or both ESMs. The list normally holds valid data whenever the drive is in the bypassed state (DRIVE_STAT_BYPASSED) , however it may be empty if the source of the bypass is unknown. It is also possible for the list to hold valid data when the drive is optimal, if only one ESM has bypassed the drive. */
	public void setBypassSource(ObjectReference[] x) {
		this.bypassSource = x;
	}

	/** This field contains the repair policy for the Drive. */
	@io.swagger.annotations.ApiModelProperty(value ="This field contains the repair policy for the Drive." , required = true)
	@XmlElement(required = true)
	private RepairPolicy repairPolicy;

	/** @return This field contains the repair policy for the Drive. */
	public RepairPolicy getRepairPolicy() {
		return this.repairPolicy;
	}
	/** @param x This field contains the repair policy for the Drive. */
	public void setRepairPolicy(RepairPolicy x) {
		this.repairPolicy = x;
	}

	/** True if the drive supports FDE, false otherwise */
	@io.swagger.annotations.ApiModelProperty(value ="True if the drive supports FDE, false otherwise" , required = true)
	@XmlElement(required = true)
	private boolean fdeCapable;

	/** @return True if the drive supports FDE, false otherwise */
	public boolean isFdeCapable() {
		return this.fdeCapable;
	}
	/** @param x True if the drive supports FDE, false otherwise */
	public void setFdeCapable(boolean x) {
		this.fdeCapable = x;
	}

	/** true if drive security is enabled; false if disabled */
	@io.swagger.annotations.ApiModelProperty(value ="true if drive security is enabled; false if disabled" , required = true)
	@XmlElement(required = true)
	private boolean fdeEnabled;

	/** @return true if drive security is enabled; false if disabled */
	public boolean isFdeEnabled() {
		return this.fdeEnabled;
	}
	/** @param x true if drive security is enabled; false if disabled */
	public void setFdeEnabled(boolean x) {
		this.fdeEnabled = x;
	}

	/** True if the drive is locked, false if the drive is unlocked */
	@io.swagger.annotations.ApiModelProperty(value ="True if the drive is locked, false if the drive is unlocked" , required = true)
	@XmlElement(required = true)
	private boolean fdeLocked;

	/** @return True if the drive is locked, false if the drive is unlocked */
	public boolean isFdeLocked() {
		return this.fdeLocked;
	}
	/** @param x True if the drive is locked, false if the drive is unlocked */
	public void setFdeLocked(boolean x) {
		this.fdeLocked = x;
	}

	/** The lock key ID as read from the drive. */
	@io.swagger.annotations.ApiModelProperty(value ="The lock key ID as read from the drive." , required = true)
	@XmlElement(required = true)
	private String lockKeyID;

	/** @return The lock key ID as read from the drive. */
	public String getLockKeyID() {
		return this.lockKeyID;
	}
	/** @param x The lock key ID as read from the drive. */
	public void setLockKeyID(String x) {
		this.lockKeyID = x;
	}

	/** Contains wear life data for the SSD drive. */
	@io.swagger.annotations.ApiModelProperty(value ="Contains wear life data for the SSD drive." , required = true)
	@XmlElement(required = true)
	private SSDWearLife ssdWearLife;

	/** @return Contains wear life data for the SSD drive. */
	public SSDWearLife getSsdWearLife() {
		return this.ssdWearLife;
	}
	/** @param x Contains wear life data for the SSD drive. */
	public void setSsdWearLife(SSDWearLife x) {
		this.ssdWearLife = x;
	}

	/** This field is set to the drive media type of the drive. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is set to the drive media type of the drive." , required = true)
	@XmlElement(required = true)
	private DriveMediaType driveMediaType = DriveMediaType.__UNDEFINED;

	/** @return This field is set to the drive media type of the drive. */
	public DriveMediaType getDriveMediaType() {
		return this.driveMediaType;
	}
	/** @param x This field is set to the drive media type of the drive. */
	public void setDriveMediaType(DriveMediaType x) {
		this.driveMediaType = x;
	}

	/** This data is a variable-length ASCII text string that identifies the version of the FPGA package. */
	@io.swagger.annotations.ApiModelProperty(value ="This data is a variable-length ASCII text string that identifies the version of the FPGA package." , required = true)
	@XmlElement(required = true)
	private String fpgaVersion;

	/** @return This data is a variable-length ASCII text string that identifies the version of the FPGA package. */
	public String getFpgaVersion() {
		return this.fpgaVersion;
	}
	/** @param x This data is a variable-length ASCII text string that identifies the version of the FPGA package. */
	public void setFpgaVersion(String x) {
		this.fpgaVersion = x;
	}

	/** This structure contains a protectionInformationCapable field which is set to true when the drive is formatted to support type 2 protection with a 512-byte logical block size, or if the drive is a type 0 drive formatted with a 520-byte logical block size. It also contains a field that is set to the protection type provided for the drive. */
	@io.swagger.annotations.ApiModelProperty(value ="This structure contains a protectionInformationCapable field which is set to true when the drive is formatted to support type 2 protection with a 512-byte logical block size, or if the drive is a type 0 drive formatted with a 520-byte logical block size. It also contains a field that is set to the protection type provided for the drive." , required = true)
	@XmlElement(required = true)
	private ProtectionInformationCapabilities protectionInformationCapabilities;

	/** @return This structure contains a protectionInformationCapable field which is set to true when the drive is formatted to support type 2 protection with a 512-byte logical block size, or if the drive is a type 0 drive formatted with a 520-byte logical block size. It also contains a field that is set to the protection type provided for the drive. */
	public ProtectionInformationCapabilities getProtectionInformationCapabilities() {
		return this.protectionInformationCapabilities;
	}
	/** @param x This structure contains a protectionInformationCapable field which is set to true when the drive is formatted to support type 2 protection with a 512-byte logical block size, or if the drive is a type 0 drive formatted with a 520-byte logical block size. It also contains a field that is set to the protection type provided for the drive. */
	public void setProtectionInformationCapabilities(ProtectionInformationCapabilities x) {
		this.protectionInformationCapabilities = x;
	}

	/** Field is no longer used. */
	@io.swagger.annotations.ApiModelProperty(value ="Field is no longer used." , required = true)
	@XmlElement(required = true)
	private boolean protectionInformationCapable;

	/** @return Field is no longer used. */
	public boolean isProtectionInformationCapable() {
		return this.protectionInformationCapable;
	}
	/** @param x Field is no longer used. */
	public void setProtectionInformationCapable(boolean x) {
		this.protectionInformationCapable = x;
	}

	/** Field is no longer used. */
	@io.swagger.annotations.ApiModelProperty(value ="Field is no longer used." , required = true)
	@XmlElement(required = true)
	private ProtectionType protectionType = ProtectionType.__UNDEFINED;

	/** @return Field is no longer used. */
	public ProtectionType getProtectionType() {
		return this.protectionType;
	}
	/** @param x Field is no longer used. */
	public void setProtectionType(ProtectionType x) {
		this.protectionType = x;
	}

	/** A value of true for this property means the drive is behind an interposer. */
	@io.swagger.annotations.ApiModelProperty(value ="A value of true for this property means the drive is behind an interposer." , required = true)
	@XmlElement(required = true)
	private boolean interposerPresent;

	/** @return A value of true for this property means the drive is behind an interposer. */
	public boolean isInterposerPresent() {
		return this.interposerPresent;
	}
	/** @param x A value of true for this property means the drive is behind an interposer. */
	public void setInterposerPresent(boolean x) {
		this.interposerPresent = x;
	}

	/** The drive interposer identifier. This field is valid only if the interposerPresent field is set to True. */
	@io.swagger.annotations.ApiModelProperty(value ="The drive interposer identifier. This field is valid only if the interposerPresent field is set to True." , required = true)
	@XmlElement(required = true)
	private String interposerRef;

	/** @return The drive interposer identifier. This field is valid only if the interposerPresent field is set to True. */
	public String getInterposerRef() {
		return this.interposerRef;
	}
	/** @param x The drive interposer identifier. This field is valid only if the interposerPresent field is set to True. */
	public void setInterposerRef(String x) {
		this.interposerRef = x;
	}

	/** The current command aging timeout value in hundreds of milliseconds. If this value is 0 the default command aging timeout value will be used, otherwise this value overrides the default value. */
	@io.swagger.annotations.ApiModelProperty(value ="The current command aging timeout value in hundreds of milliseconds. If this value is 0 the default command aging timeout value will be used, otherwise this value overrides the default value." , required = true)
	@XmlElement(required = true)
	private int currentCommandAgingTimeout;

	/** @return The current command aging timeout value in hundreds of milliseconds. If this value is 0 the default command aging timeout value will be used, otherwise this value overrides the default value. */
	public int getCurrentCommandAgingTimeout() {
		return this.currentCommandAgingTimeout;
	}
	/** @param x The current command aging timeout value in hundreds of milliseconds. If this value is 0 the default command aging timeout value will be used, otherwise this value overrides the default value. */
	public void setCurrentCommandAgingTimeout(int x) {
		this.currentCommandAgingTimeout = x;
	}

	/** The default command aging timeout value in hundreds of milliseconds as specified by the drive. If this value is 0, the drive command aging timeout cannot be changed. */
	@io.swagger.annotations.ApiModelProperty(value ="The default command aging timeout value in hundreds of milliseconds as specified by the drive. If this value is 0, the drive command aging timeout cannot be changed." , required = true)
	@XmlElement(required = true)
	private int defaultCommandAgingTimeout;

	/** @return The default command aging timeout value in hundreds of milliseconds as specified by the drive. If this value is 0, the drive command aging timeout cannot be changed. */
	public int getDefaultCommandAgingTimeout() {
		return this.defaultCommandAgingTimeout;
	}
	/** @param x The default command aging timeout value in hundreds of milliseconds as specified by the drive. If this value is 0, the drive command aging timeout cannot be changed. */
	public void setDefaultCommandAgingTimeout(int x) {
		this.defaultCommandAgingTimeout = x;
	}

	/** Drive temperature data. */
	@io.swagger.annotations.ApiModelProperty(value ="Drive temperature data." , required = true)
	@XmlElement(required = true)
	private DriveTemperature driveTemperature;

	/** @return Drive temperature data. */
	public DriveTemperature getDriveTemperature() {
		return this.driveTemperature;
	}
	/** @param x Drive temperature data. */
	public void setDriveTemperature(DriveTemperature x) {
		this.driveTemperature = x;
	}

	/** The physical block (i.e., sector) size for the drive, represented in bytes. This field is valid for missing drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The physical block (i.e., sector) size for the drive, represented in bytes. This field is valid for missing drives." , required = true)
	@XmlElement(required = true)
	private int blkSizePhysical;

	/** @return The physical block (i.e., sector) size for the drive, represented in bytes. This field is valid for missing drives. */
	public int getBlkSizePhysical() {
		return this.blkSizePhysical;
	}
	/** @param x The physical block (i.e., sector) size for the drive, represented in bytes. This field is valid for missing drives. */
	public void setBlkSizePhysical(int x) {
		this.blkSizePhysical = x;
	}

	/** The lowest aligned LBA for the physical sector. Typically this will be 0, but could be non-zero for emulation drives where LBA 0 starts at some logical sector offset within the physical sector. */
	@io.swagger.annotations.ApiModelProperty(value ="The lowest aligned LBA for the physical sector. Typically this will be 0, but could be non-zero for emulation drives where LBA 0 starts at some logical sector offset within the physical sector." , required = true)
	@XmlElement(required = true)
	private long lowestAlignedLBA;

	/** @return The lowest aligned LBA for the physical sector. Typically this will be 0, but could be non-zero for emulation drives where LBA 0 starts at some logical sector offset within the physical sector. */
	public long getLowestAlignedLBA() {
		return this.lowestAlignedLBA;
	}
	/** @param x The lowest aligned LBA for the physical sector. Typically this will be 0, but could be non-zero for emulation drives where LBA 0 starts at some logical sector offset within the physical sector. */
	public void setLowestAlignedLBA(long x) {
		this.lowestAlignedLBA = x;
	}

	/** True if the drive is in the process of being removed from the volume group. Only applies to Disk Pools */
	@io.swagger.annotations.ApiModelProperty(value ="True if the drive is in the process of being removed from the volume group. Only applies to Disk Pools" , required = true)
	@XmlElement(required = true)
	private boolean removed;

	/** @return True if the drive is in the process of being removed from the volume group. Only applies to Disk Pools */
	public boolean isRemoved() {
		return this.removed;
	}
	/** @param x True if the drive is in the process of being removed from the volume group. Only applies to Disk Pools */
	public void setRemoved(boolean x) {
		this.removed = x;
	}

	/** Indicates that a locate operation for the device is currently active. The device will show a visual indication to aid an operator in locating the drive. */
	@io.swagger.annotations.ApiModelProperty(value ="Indicates that a locate operation for the device is currently active. The device will show a visual indication to aid an operator in locating the drive." , required = true)
	@XmlElement(required = true)
	private boolean locateInProgress;

	/** @return Indicates that a locate operation for the device is currently active. The device will show a visual indication to aid an operator in locating the drive. */
	public boolean isLocateInProgress() {
		return this.locateInProgress;
	}
	/** @param x Indicates that a locate operation for the device is currently active. The device will show a visual indication to aid an operator in locating the drive. */
	public void setLocateInProgress(boolean x) {
		this.locateInProgress = x;
	}

	/** This flag is true if the drive supports FIPS (Federal Information Processing Standard). FIPS 140-2 specification. */
	@io.swagger.annotations.ApiModelProperty(value ="This flag is true if the drive supports FIPS (Federal Information Processing Standard). FIPS 140-2 specification." , required = true)
	@XmlElement(required = true)
	private boolean fipsCapable;

	/** @return This flag is true if the drive supports FIPS (Federal Information Processing Standard). FIPS 140-2 specification. */
	public boolean isFipsCapable() {
		return this.fipsCapable;
	}
	/** @param x This flag is true if the drive supports FIPS (Federal Information Processing Standard). FIPS 140-2 specification. */
	public void setFipsCapable(boolean x) {
		this.fipsCapable = x;
	}
	@Override
	public String getId(){
		return driveRef;
	}
}
