package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This contains various pieces of statistical counter data that are reported for an InfiniBand interface. This structure can be used for counter values that are raw (ibInterfacesStatisticsRaw) or relative (ibInterfaceStatisticsRel) counter values. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(747)
public class EnhancedIbInterfaceStatistics implements Serializable {
	public EnhancedIbInterfaceStatistics() {
	}

	/** A reference to the interface for which the statistics apply. */
	@io.swagger.annotations.ApiModelProperty(value ="A reference to the interface for which the statistics apply." , required = true)
	@XmlElement(required = true)
	private String interfaceRef;

	/** @return A reference to the interface for which the statistics apply. */
	public String getInterfaceRef() {
		return this.interfaceRef;
	}
	/** @param x A reference to the interface for which the statistics apply. */
	public void setInterfaceRef(String x) {
		this.interfaceRef = x;
	}

	/** The number of symbol errors. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of symbol errors." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer symbolErrors;

	/** @return The number of symbol errors. */
	public StatisticalContainer getSymbolErrors() {
		return this.symbolErrors;
	}
	/** @param x The number of symbol errors. */
	public void setSymbolErrors(StatisticalContainer x) {
		this.symbolErrors = x;
	}

	/** The number of recovered link errors. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of recovered link errors." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer recoveredLinkErrors;

	/** @return The number of recovered link errors. */
	public StatisticalContainer getRecoveredLinkErrors() {
		return this.recoveredLinkErrors;
	}
	/** @param x The number of recovered link errors. */
	public void setRecoveredLinkErrors(StatisticalContainer x) {
		this.recoveredLinkErrors = x;
	}

	/** The number of unrecovered link errors. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of unrecovered link errors." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer unrecoveredLinkErrors;

	/** @return The number of unrecovered link errors. */
	public StatisticalContainer getUnrecoveredLinkErrors() {
		return this.unrecoveredLinkErrors;
	}
	/** @param x The number of unrecovered link errors. */
	public void setUnrecoveredLinkErrors(StatisticalContainer x) {
		this.unrecoveredLinkErrors = x;
	}

	/** The number of packets containing an error that have been received on the port. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of packets containing an error that have been received on the port." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer rxPacketErrors;

	/** @return The number of packets containing an error that have been received on the port. */
	public StatisticalContainer getRxPacketErrors() {
		return this.rxPacketErrors;
	}
	/** @param x The number of packets containing an error that have been received on the port. */
	public void setRxPacketErrors(StatisticalContainer x) {
		this.rxPacketErrors = x;
	}

	/** The total number of packets with End Bad Packet delimiter that have been received on the port. */
	@io.swagger.annotations.ApiModelProperty(value ="The total number of packets with End Bad Packet delimiter that have been received on the port." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer rxEbpDelimitedPackets;

	/** @return The total number of packets with End Bad Packet delimiter that have been received on the port. */
	public StatisticalContainer getRxEbpDelimitedPackets() {
		return this.rxEbpDelimitedPackets;
	}
	/** @param x The total number of packets with End Bad Packet delimiter that have been received on the port. */
	public void setRxEbpDelimitedPackets(StatisticalContainer x) {
		this.rxEbpDelimitedPackets = x;
	}

	/** The number of outbound packets discarded because the port is either down or congested. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of outbound packets discarded because the port is either down or congested." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer txPortDownPacketDiscards;

	/** @return The number of outbound packets discarded because the port is either down or congested. */
	public StatisticalContainer getTxPortDownPacketDiscards() {
		return this.txPortDownPacketDiscards;
	}
	/** @param x The number of outbound packets discarded because the port is either down or congested. */
	public void setTxPortDownPacketDiscards(StatisticalContainer x) {
		this.txPortDownPacketDiscards = x;
	}

	/** The number of outbound packets discarded because either (1) the packet is a raw datagram, (2) the packet has a wrong partition key, or (3) the packet has a bad transport header version. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of outbound packets discarded because either (1) the packet is a raw datagram, (2) the packet has a wrong partition key, or (3) the packet has a bad transport header version." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer txConstraintErrorPacketDiscards;

	/** @return The number of outbound packets discarded because either (1) the packet is a raw datagram, (2) the packet has a wrong partition key, or (3) the packet has a bad transport header version. */
	public StatisticalContainer getTxConstraintErrorPacketDiscards() {
		return this.txConstraintErrorPacketDiscards;
	}
	/** @param x The number of outbound packets discarded because either (1) the packet is a raw datagram, (2) the packet has a wrong partition key, or (3) the packet has a bad transport header version. */
	public void setTxConstraintErrorPacketDiscards(StatisticalContainer x) {
		this.txConstraintErrorPacketDiscards = x;
	}

	/** The number of inbound packets discarded because either (1) the packet is a raw datagram, (2) the packet has a wrong partition key, or (3) the packet has a bad transport header version. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of inbound packets discarded because either (1) the packet is a raw datagram, (2) the packet has a wrong partition key, or (3) the packet has a bad transport header version." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer rxConstraintErrorPacketDiscards;

	/** @return The number of inbound packets discarded because either (1) the packet is a raw datagram, (2) the packet has a wrong partition key, or (3) the packet has a bad transport header version. */
	public StatisticalContainer getRxConstraintErrorPacketDiscards() {
		return this.rxConstraintErrorPacketDiscards;
	}
	/** @param x The number of inbound packets discarded because either (1) the packet is a raw datagram, (2) the packet has a wrong partition key, or (3) the packet has a bad transport header version. */
	public void setRxConstraintErrorPacketDiscards(StatisticalContainer x) {
		this.rxConstraintErrorPacketDiscards = x;
	}

	/** The number of virtual lane 15 packets dropped due to resource limitations (e.g., lack of buffers) in the port. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of virtual lane 15 packets dropped due to resource limitations (e.g., lack of buffers) in the port." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer rxSubnetManagementDroppedPackets;

	/** @return The number of virtual lane 15 packets dropped due to resource limitations (e.g., lack of buffers) in the port. */
	public StatisticalContainer getRxSubnetManagementDroppedPackets() {
		return this.rxSubnetManagementDroppedPackets;
	}
	/** @param x The number of virtual lane 15 packets dropped due to resource limitations (e.g., lack of buffers) in the port. */
	public void setRxSubnetManagementDroppedPackets(StatisticalContainer x) {
		this.rxSubnetManagementDroppedPackets = x;
	}

	/** The number of bytes transmitted at the port on all virtual lanes. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of bytes transmitted at the port on all virtual lanes." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer txTotalBytes;

	/** @return The number of bytes transmitted at the port on all virtual lanes. */
	public StatisticalContainer getTxTotalBytes() {
		return this.txTotalBytes;
	}
	/** @param x The number of bytes transmitted at the port on all virtual lanes. */
	public void setTxTotalBytes(StatisticalContainer x) {
		this.txTotalBytes = x;
	}

	/** The number of bytes received at the port on all virtual lanes. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of bytes received at the port on all virtual lanes." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer rxTotalBytes;

	/** @return The number of bytes received at the port on all virtual lanes. */
	public StatisticalContainer getRxTotalBytes() {
		return this.rxTotalBytes;
	}
	/** @param x The number of bytes received at the port on all virtual lanes. */
	public void setRxTotalBytes(StatisticalContainer x) {
		this.rxTotalBytes = x;
	}

	/** The number of packets transmitted at the port on all virtual lanes. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of packets transmitted at the port on all virtual lanes." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer txTotalPackets;

	/** @return The number of packets transmitted at the port on all virtual lanes. */
	public StatisticalContainer getTxTotalPackets() {
		return this.txTotalPackets;
	}
	/** @param x The number of packets transmitted at the port on all virtual lanes. */
	public void setTxTotalPackets(StatisticalContainer x) {
		this.txTotalPackets = x;
	}

	/** The number of packets received at the port on all virtual lanes. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of packets received at the port on all virtual lanes." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer rxTotalPackets;

	/** @return The number of packets received at the port on all virtual lanes. */
	public StatisticalContainer getRxTotalPackets() {
		return this.rxTotalPackets;
	}
	/** @param x The number of packets received at the port on all virtual lanes. */
	public void setRxTotalPackets(StatisticalContainer x) {
		this.rxTotalPackets = x;
	}

	/** The number of microseconds during which the port had data to transmit, but none was sent because of insufficient credits or due to arbitration. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of microseconds during which the port had data to transmit, but none was sent because of insufficient credits or due to arbitration." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer txWaitTime;

	/** @return The number of microseconds during which the port had data to transmit, but none was sent because of insufficient credits or due to arbitration. */
	public StatisticalContainer getTxWaitTime() {
		return this.txWaitTime;
	}
	/** @param x The number of microseconds during which the port had data to transmit, but none was sent because of insufficient credits or due to arbitration. */
	public void setTxWaitTime(StatisticalContainer x) {
		this.txWaitTime = x;
	}

	/** Total number of unicast packets transmitted on all VLs from the port. This may include unicast packets with errors and excludes link packets. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of unicast packets transmitted on all VLs from the port. This may include unicast packets with errors and excludes link packets." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer txUnicastTotalPackets;

	/** @return Total number of unicast packets transmitted on all VLs from the port. This may include unicast packets with errors and excludes link packets. */
	public StatisticalContainer getTxUnicastTotalPackets() {
		return this.txUnicastTotalPackets;
	}
	/** @param x Total number of unicast packets transmitted on all VLs from the port. This may include unicast packets with errors and excludes link packets. */
	public void setTxUnicastTotalPackets(StatisticalContainer x) {
		this.txUnicastTotalPackets = x;
	}

	/** Total number of unicast packets, including unicast packets containing errors, and excluding link packets, received from all VLs on the port. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of unicast packets, including unicast packets containing errors, and excluding link packets, received from all VLs on the port." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer rxUnicastTotalPackets;

	/** @return Total number of unicast packets, including unicast packets containing errors, and excluding link packets, received from all VLs on the port. */
	public StatisticalContainer getRxUnicastTotalPackets() {
		return this.rxUnicastTotalPackets;
	}
	/** @param x Total number of unicast packets, including unicast packets containing errors, and excluding link packets, received from all VLs on the port. */
	public void setRxUnicastTotalPackets(StatisticalContainer x) {
		this.rxUnicastTotalPackets = x;
	}

	/** Total number of multicast packets transmitted on all VLs from the port. This may include multicast packets with errors. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of multicast packets transmitted on all VLs from the port. This may include multicast packets with errors." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer txMulticastTotalPackets;

	/** @return Total number of multicast packets transmitted on all VLs from the port. This may include multicast packets with errors. */
	public StatisticalContainer getTxMulticastTotalPackets() {
		return this.txMulticastTotalPackets;
	}
	/** @param x Total number of multicast packets transmitted on all VLs from the port. This may include multicast packets with errors. */
	public void setTxMulticastTotalPackets(StatisticalContainer x) {
		this.txMulticastTotalPackets = x;
	}

	/** Total number of multicast packets, including multicast packets containing errors received from all VLs on the port. */
	@io.swagger.annotations.ApiModelProperty(value ="Total number of multicast packets, including multicast packets containing errors received from all VLs on the port." , required = true)
	@XmlElement(required = true)
	private StatisticalContainer rxMulticastTotalPackets;

	/** @return Total number of multicast packets, including multicast packets containing errors received from all VLs on the port. */
	public StatisticalContainer getRxMulticastTotalPackets() {
		return this.rxMulticastTotalPackets;
	}
	/** @param x Total number of multicast packets, including multicast packets containing errors received from all VLs on the port. */
	public void setRxMulticastTotalPackets(StatisticalContainer x) {
		this.rxMulticastTotalPackets = x;
	}
}
