package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration contains the legal values of the Infiniband port state. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(34)
public enum IbPhysPortState implements Serializable {
		/** The state of the Infiniband port is unknown. */
		unknown(0),
		/** In this super state, the port drives its outputs to quiescent levels and responds to received training sequences. */
		sleep(1),
		/** In this super state, the port transmits training sequences and responds to received training sequences. This is the default state following power on. */
		polling(2),
		/** Port drives its outputs to quiescent levels and does not respond to received data. */
		disabled(3),
		/** A transient super state with both the transmitter and receiver active. The port is attempting to configure and transition to the LinkUp state. */
		cfgTrain(4),
		/** This is the normal link operation state. The port is available to transfer packets. */
		linkUp(5),
		/** The recovery super state attempts to re-synchronize the link and return it to normal operation. This state is entered when a port experiences loss of link synchronization, a major error, or when a link layer error triggers error recovery. */
		linkErrRec(6),
		/** The Physical Layer test state allows simplified testing to determine compliance of physical layer transmitter driver and receiver circuitry with specified requirements. This state is defined for Enhanced Signaling, and is not implemented in products not supporting Enhanced Signaling. */
		phyTest(7),
		__UNDEFINED(464378545);

		public final int value;

		private IbPhysPortState(int v) {
			this.value = v;
		}
}
