package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to convey information about IPV6-related configuration settings */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(595)
public class InternetProtocolV6Data implements Serializable {
	public InternetProtocolV6Data() {
	}

	/** The set of IPV6 local addresses that have been assigned to the iSCSI Ethernet port. */
	@io.swagger.annotations.ApiModelProperty(value ="The set of IPV6 local addresses that have been assigned to the iSCSI Ethernet port." , required = true)
	@XmlElement(required = true)
	private IpV6AddressData[] ipv6LocalAddresses;

	/** @return The set of IPV6 local addresses that have been assigned to the iSCSI Ethernet port. */
	public IpV6AddressData[] getIpv6LocalAddresses() {
		return this.ipv6LocalAddresses;
	}
	/** @param x The set of IPV6 local addresses that have been assigned to the iSCSI Ethernet port. */
	public void setIpv6LocalAddresses(IpV6AddressData[] x) {
		this.ipv6LocalAddresses = x;
	}

	/** The set of IPV6 routable addresses that have been assigned to the iSCSI Ethernet port */
	@io.swagger.annotations.ApiModelProperty(value ="The set of IPV6 routable addresses that have been assigned to the iSCSI Ethernet port" , required = true)
	@XmlElement(required = true)
	private IpV6AddressData[] ipv6RoutableAddresses;

	/** @return The set of IPV6 routable addresses that have been assigned to the iSCSI Ethernet port */
	public IpV6AddressData[] getIpv6RoutableAddresses() {
		return this.ipv6RoutableAddresses;
	}
	/** @param x The set of IPV6 routable addresses that have been assigned to the iSCSI Ethernet port */
	public void setIpv6RoutableAddresses(IpV6AddressData[] x) {
		this.ipv6RoutableAddresses = x;
	}

	/** The IPV6 address of the port router. */
	@io.swagger.annotations.ApiModelProperty(value ="The IPV6 address of the port router." , required = true)
	@XmlElement(required = true)
	private IpV6AddressData ipv6PortRouterAddress;

	/** @return The IPV6 address of the port router. */
	public IpV6AddressData getIpv6PortRouterAddress() {
		return this.ipv6PortRouterAddress;
	}
	/** @param x The IPV6 address of the port router. */
	public void setIpv6PortRouterAddress(IpV6AddressData x) {
		this.ipv6PortRouterAddress = x;
	}

	/** The method by which the IPV6 address information is configured for the endpoint. */
	@io.swagger.annotations.ApiModelProperty(value ="The method by which the IPV6 address information is configured for the endpoint." , required = true)
	@XmlElement(required = true)
	private IpV6ConfigMethod ipv6AddressConfigMethod = IpV6ConfigMethod.__UNDEFINED;

	/** @return The method by which the IPV6 address information is configured for the endpoint. */
	public IpV6ConfigMethod getIpv6AddressConfigMethod() {
		return this.ipv6AddressConfigMethod;
	}
	/** @param x The method by which the IPV6 address information is configured for the endpoint. */
	public void setIpv6AddressConfigMethod(IpV6ConfigMethod x) {
		this.ipv6AddressConfigMethod = x;
	}

	/** Settings that govern the priority to associate with outbound IPV6 packets sent over the interface */
	@io.swagger.annotations.ApiModelProperty(value ="Settings that govern the priority to associate with outbound IPV6 packets sent over the interface" , required = true)
	@XmlElement(required = true)
	private SettingControl ipv6OutboundPacketPriority;

	/** @return Settings that govern the priority to associate with outbound IPV6 packets sent over the interface */
	public SettingControl getIpv6OutboundPacketPriority() {
		return this.ipv6OutboundPacketPriority;
	}
	/** @param x Settings that govern the priority to associate with outbound IPV6 packets sent over the interface */
	public void setIpv6OutboundPacketPriority(SettingControl x) {
		this.ipv6OutboundPacketPriority = x;
	}

	/** Settings that govern the value of the IPV6 VLAN identifier for the interface. VLAN identifiers are in the range 1 through 4094. */
	@io.swagger.annotations.ApiModelProperty(value ="Settings that govern the value of the IPV6 VLAN identifier for the interface. VLAN identifiers are in the range 1 through 4094." , required = true)
	@XmlElement(required = true)
	private SettingControl ipv6VlanId;

	/** @return Settings that govern the value of the IPV6 VLAN identifier for the interface. VLAN identifiers are in the range 1 through 4094. */
	public SettingControl getIpv6VlanId() {
		return this.ipv6VlanId;
	}
	/** @param x Settings that govern the value of the IPV6 VLAN identifier for the interface. VLAN identifiers are in the range 1 through 4094. */
	public void setIpv6VlanId(SettingControl x) {
		this.ipv6VlanId = x;
	}

	/** The hop limit to use in IPV6 packets sent over the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The hop limit to use in IPV6 packets sent over the interface." , required = true)
	@XmlElement(required = true)
	private short ipv6HopLimit;

	/** @return The hop limit to use in IPV6 packets sent over the interface. */
	public short getIpv6HopLimit() {
		return this.ipv6HopLimit;
	}
	/** @param x The hop limit to use in IPV6 packets sent over the interface. */
	public void setIpv6HopLimit(short x) {
		this.ipv6HopLimit = x;
	}

	/** A "neighbor discovery" parameter - the amount of time in milliseconds, within which a neighbor is assumed to be reachable. */
	@io.swagger.annotations.ApiModelProperty(value ="A \"neighbor discovery\" parameter - the amount of time in milliseconds, within which a neighbor is assumed to be reachable." , required = true)
	@XmlElement(required = true)
	private int ipv6NdReachableTime;

	/** @return A "neighbor discovery" parameter - the amount of time in milliseconds, within which a neighbor is assumed to be reachable. */
	public int getIpv6NdReachableTime() {
		return this.ipv6NdReachableTime;
	}
	/** @param x A "neighbor discovery" parameter - the amount of time in milliseconds, within which a neighbor is assumed to be reachable. */
	public void setIpv6NdReachableTime(int x) {
		this.ipv6NdReachableTime = x;
	}

	/** A "neighbor discovery" parameter - the number of milliseconds between neighbor solicitation probes. */
	@io.swagger.annotations.ApiModelProperty(value ="A \"neighbor discovery\" parameter - the number of milliseconds between neighbor solicitation probes." , required = true)
	@XmlElement(required = true)
	private int ipv6NdRetransmitTime;

	/** @return A "neighbor discovery" parameter - the number of milliseconds between neighbor solicitation probes. */
	public int getIpv6NdRetransmitTime() {
		return this.ipv6NdRetransmitTime;
	}
	/** @param x A "neighbor discovery" parameter - the number of milliseconds between neighbor solicitation probes. */
	public void setIpv6NdRetransmitTime(int x) {
		this.ipv6NdRetransmitTime = x;
	}

	/** A "neighbor discovery" parameter - the time in milliseconds after which information for a neighbor that cannot be verified as reachable will be considered "stale." */
	@io.swagger.annotations.ApiModelProperty(value ="A \"neighbor discovery\" parameter - the time in milliseconds after which information for a neighbor that cannot be verified as reachable will be considered \"stale.\"" , required = true)
	@XmlElement(required = true)
	private int ipv6NdStaleTimeout;

	/** @return A "neighbor discovery" parameter - the time in milliseconds after which information for a neighbor that cannot be verified as reachable will be considered "stale." */
	public int getIpv6NdStaleTimeout() {
		return this.ipv6NdStaleTimeout;
	}
	/** @param x A "neighbor discovery" parameter - the time in milliseconds after which information for a neighbor that cannot be verified as reachable will be considered "stale." */
	public void setIpv6NdStaleTimeout(int x) {
		this.ipv6NdStaleTimeout = x;
	}

	/** The number of neighbor-solicitation messages to send in trying to determine IP address uniqueness. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of neighbor-solicitation messages to send in trying to determine IP address uniqueness." , required = true)
	@XmlElement(required = true)
	private short ipv6DuplicateAddressDetectionAttempts;

	/** @return The number of neighbor-solicitation messages to send in trying to determine IP address uniqueness. */
	public short getIpv6DuplicateAddressDetectionAttempts() {
		return this.ipv6DuplicateAddressDetectionAttempts;
	}
	/** @param x The number of neighbor-solicitation messages to send in trying to determine IP address uniqueness. */
	public void setIpv6DuplicateAddressDetectionAttempts(short x) {
		this.ipv6DuplicateAddressDetectionAttempts = x;
	}
}
