package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration type identifies the possible states of a volume group. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(46)
public enum VolumeGroupState implements Serializable {
		/** A state in which it is likely, but not certain that the volume group will become complete and be made available for import. Generally, as long as a proper, non-empty subset of constituent drives remain in the group, the group remains in the contingent state. */
		contingent(1),
		/** A state in which the volume group is ready for import or is exported. */
		exported(2),
		/** A state in which the volume group has been declared by an administrator to be ready for import. */
		forced(3),
		/** A state in which all constituent drives of the volume group are assigned, present, and online; and in which the volume group is fully operable. */
		complete(4),
		/** A state in which some or all redundancy of the group is lost, but in which the data is still accessible. The volume group is operable, but not exportable. */
		partial(5),
		/** A state in which the subset of constituent drives available in the volume group is insufficient to allow processing of data. The volume group is neither operable nor exportable. */
		incomplete(6),
		/** A state in which all constituent drives of the volume group have been removed from the array. The volume group is neither operable nor exportable. */
		missing(7),
		__UNDEFINED(464378545);

		public final int value;

		private VolumeGroupState(int v) {
			this.value = v;
		}
}
